==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QExposeEvent_shell.cpp <==
#include "QExposeEvent_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QExposeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QExposeEvent")
    QExposeEvent *_ptr = reinterpret_cast<QExposeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QExposeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QExposeEvent_shell) ); }

jmethodID QExposeEvent_shell::__shell_javaMethod(int pos) const { return QExposeEvent_shell::__shell()->javaMethod(typeid(QExposeEvent), pos); }

// emitting (writeShellConstructor)
QExposeEvent_shell::QExposeEvent_shell(const QExposeEvent& arg__1)
    : QExposeEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QExposeEvent::QExposeEvent_shell(const QExposeEvent& arg__1)", QExposeEvent_shell::__shell())
    QExposeEvent_shell::__shell()->constructed(typeid(QExposeEvent));
}

QExposeEvent_shell::QExposeEvent_shell(const QRegion& m_region0)
    : QExposeEvent(m_region0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QExposeEvent::QExposeEvent_shell(const QRegion& m_region0)", QExposeEvent_shell::__shell())
    QExposeEvent_shell::__shell()->constructed(typeid(QExposeEvent));
}

// emitting (writeShellDestructor)
QExposeEvent_shell::~QExposeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QExposeEvent::~QExposeEvent()", QExposeEvent_shell::__shell())
    QExposeEvent_shell::__shell()->destructed(typeid(QExposeEvent));
}

void QExposeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QExposeEvent_shell*>(ptr)->QExposeEvent_shell::__shell()->tryDeleteShell(typeid(QExposeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QExposeEvent* QExposeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QExposeEvent::clone()const", QExposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QExposeEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QExposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QExposeEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QExposeEvent_shell::__shell()->warnForMethod("QExposeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QExposeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QExposeEvent::clone();
        }
    }else{
        return QExposeEvent::clone();
    }
}

void QExposeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QExposeEvent::", QExposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QExposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QExposeEvent_shell::__shell()->warnForMethod("QExposeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QExposeEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QExposeEvent_access::__qt_assign_cref_QExposeEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QExposeEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QExposeEvent>(__jni_env, other0);
    QExposeEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QExposeEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QExposeEvent* __qt_return_value = QExposeEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QExposeEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QExposeEvent(QExposeEvent)
void __qt_construct_QExposeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QExposeEvent(QExposeEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QExposeEvent& __qt_arg__1 = qtjambi_cast<const QExposeEvent& >(__jni_env, arg__1);
    QExposeEvent *__qt_this = new(__qtjambi_ptr) QExposeEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QExposeEvent(QRegion)
void __qt_construct_QExposeEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QExposeEvent(QRegion)")
    jobject m_region0 = __java_arguments[0].l;
    const QRegion& __qt_m_region0 = qtjambi_cast<const QRegion& >(__jni_env, m_region0);
    QExposeEvent *__qt_this = new(__qtjambi_ptr) QExposeEvent_shell(__qt_m_region0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QExposeEvent_shell
void __qt_destruct_QExposeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QExposeEvent")
    reinterpret_cast<QExposeEvent_shell*>(ptr)->~QExposeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QExposeEvent::QExposeEvent(QExposeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_initialize_1native__Lio_qt_gui_QExposeEvent_2Lio_qt_gui_QExposeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QExposeEvent::QExposeEvent(QExposeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QExposeEvent_0, sizeof(QExposeEvent_shell), typeid(QExposeEvent), true, &deleter_QExposeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QExposeEvent::QExposeEvent(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_initialize_1native__Lio_qt_gui_QExposeEvent_2Lio_qt_gui_QRegion_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject m_region0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QExposeEvent::QExposeEvent(QRegion)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = m_region0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QExposeEvent_1, sizeof(QExposeEvent_shell), typeid(QExposeEvent), true, &deleter_QExposeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QExposeEvent::operator=(QExposeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_assign_1native_1cref_1QExposeEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QExposeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QExposeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QExposeEvent::operator=(QExposeEvent)", __qt_this)
        static_cast<QExposeEvent_access*>(__qt_this)->__qt_assign_cref_QExposeEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QExposeEvent::region()const
extern "C" QT_DEPRECATED Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_region_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QExposeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QExposeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QExposeEvent::region()const", __qt_this)
        const QRegion& __qt_return_value = __qt_this->region();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QExposeEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QExposeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QExposeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QExposeEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QExposeEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QExposeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QExposeEvent>("QExposeEvent", "io/qt/gui/QExposeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QExposeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QExposeEvent, {
        ConstructorInfo(&__qt_construct_QExposeEvent_0, "Lio/qt/gui/QExposeEvent;")
       ,ConstructorInfo(&__qt_construct_QExposeEvent_1, "Lio/qt/gui/QRegion;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QExposeEvent);
    registerSizeOfShell(typeId, sizeof(QExposeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QExposeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QExposeEvent_shell.cpp <==
#include "QExposeEvent_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QExposeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QExposeEvent")
    QExposeEvent *_ptr = reinterpret_cast<QExposeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QExposeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QExposeEvent_shell) ); }

jmethodID QExposeEvent_shell::__shell_javaMethod(int pos) const { return QExposeEvent_shell::__shell()->javaMethod(typeid(QExposeEvent), pos); }

// emitting (writeShellConstructor)
QExposeEvent_shell::QExposeEvent_shell(const QExposeEvent& arg__1)
    : QExposeEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QExposeEvent::QExposeEvent_shell(const QExposeEvent& arg__1)", QExposeEvent_shell::__shell())
    QExposeEvent_shell::__shell()->constructed(typeid(QExposeEvent));
}

QExposeEvent_shell::QExposeEvent_shell(const QRegion& m_region0)
    : QExposeEvent(m_region0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QExposeEvent::QExposeEvent_shell(const QRegion& m_region0)", QExposeEvent_shell::__shell())
    QExposeEvent_shell::__shell()->constructed(typeid(QExposeEvent));
}

// emitting (writeShellDestructor)
QExposeEvent_shell::~QExposeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QExposeEvent::~QExposeEvent()", QExposeEvent_shell::__shell())
    QExposeEvent_shell::__shell()->destructed(typeid(QExposeEvent));
}

void QExposeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QExposeEvent_shell*>(ptr)->QExposeEvent_shell::__shell()->tryDeleteShell(typeid(QExposeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QExposeEvent* QExposeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QExposeEvent::clone()const", QExposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QExposeEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QExposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QExposeEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QExposeEvent_shell::__shell()->warnForMethod("QExposeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QExposeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QExposeEvent::clone();
        }
    }else{
        return QExposeEvent::clone();
    }
}

void QExposeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QExposeEvent::", QExposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QExposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QExposeEvent_shell::__shell()->warnForMethod("QExposeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QExposeEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QExposeEvent_access::__qt_assign_cref_QExposeEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QExposeEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QExposeEvent>(__jni_env, other0);
    QExposeEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QExposeEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QExposeEvent* __qt_return_value = QExposeEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QExposeEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QExposeEvent(QExposeEvent)
void __qt_construct_QExposeEvent_cref_QExposeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QExposeEvent(QExposeEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QExposeEvent& __qt_arg__1 = qtjambi_cast<const QExposeEvent& >(__jni_env, arg__1);
    QExposeEvent *__qt_this = new(__qtjambi_ptr) QExposeEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QExposeEvent::QExposeEvent(QExposeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_initialize_1native__Lio_qt_gui_QExposeEvent_2Lio_qt_gui_QExposeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QExposeEvent::QExposeEvent(QExposeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QExposeEvent_cref_QExposeEvent, sizeof(QExposeEvent_shell), typeid(QExposeEvent), true, &deleter_QExposeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QExposeEvent(QRegion)
void __qt_construct_QExposeEvent_cref_QRegion(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QExposeEvent(QRegion)")
    jobject m_region0 = __java_arguments[0].l;
    const QRegion& __qt_m_region0 = qtjambi_cast<const QRegion& >(__jni_env, m_region0);
    QExposeEvent *__qt_this = new(__qtjambi_ptr) QExposeEvent_shell(__qt_m_region0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QExposeEvent::QExposeEvent(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_initialize_1native__Lio_qt_gui_QExposeEvent_2Lio_qt_gui_QRegion_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject m_region0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QExposeEvent::QExposeEvent(QRegion)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = m_region0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QExposeEvent_cref_QRegion, sizeof(QExposeEvent_shell), typeid(QExposeEvent), true, &deleter_QExposeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QExposeEvent_shell
void __qt_destruct_QExposeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QExposeEvent")
    reinterpret_cast<QExposeEvent_shell*>(ptr)->~QExposeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QExposeEvent::operator=(QExposeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_assign_1native_1cref_1QExposeEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QExposeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QExposeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QExposeEvent::operator=(QExposeEvent)", __qt_this)
        static_cast<QExposeEvent_access*>(__qt_this)->__qt_assign_cref_QExposeEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QExposeEvent::region()const
extern "C" QT_DEPRECATED Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_region_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QExposeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QExposeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QExposeEvent::region()const", __qt_this)
        const QRegion& __qt_return_value = __qt_this->region();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QExposeEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QExposeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QExposeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QExposeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QExposeEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QExposeEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QExposeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QExposeEvent>("QExposeEvent", "io/qt/gui/QExposeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QExposeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QExposeEvent, {
        ConstructorInfo(&__qt_construct_QExposeEvent_cref_QExposeEvent, "Lio/qt/gui/QExposeEvent;")
       ,ConstructorInfo(&__qt_construct_QExposeEvent_cref_QRegion, "Lio/qt/gui/QRegion;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QExposeEvent);
    registerSizeOfShell(typeId, sizeof(QExposeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QExposeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
